Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: content/browser/tab_contents/tab_contents.cc

Issue 7054046: Disable GPU compositing and accelerated 2d canvas for about: URLs (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/tab_contents/tab_contents.cc
diff --git a/content/browser/tab_contents/tab_contents.cc b/content/browser/tab_contents/tab_contents.cc
index 8aedfa7f9c46290c8475116fd9ad46800072ad3b..46a10a4372b1d4a9611b5809d291974d1959b89a 100644
--- a/content/browser/tab_contents/tab_contents.cc
+++ b/content/browser/tab_contents/tab_contents.cc
@@ -1623,10 +1623,11 @@ WebPreferences TabContents::GetWebkitPrefs() {
WebPreferences web_prefs =
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_web_ui);
// Force accelerated compositing and 2d canvas off for chrome: and
// chrome-extension: pages.
if (GetURL().SchemeIs(chrome::kChromeDevToolsScheme) ||
- GetURL().SchemeIs(chrome::kChromeUIScheme)) {
+ GetURL().SchemeIs(chrome::kChromeUIScheme) ||
+ GetURL().SchemeIs(chrome::kAboutScheme)) {
web_prefs.accelerated_compositing_enabled = false;
web_prefs.accelerated_2d_canvas_enabled = false;
}
@@ -1623,10 +1623,11 @@ WebPreferences TabContents::GetWebkitPrefs() {
WebPreferences web_prefs =
RenderViewHostDelegateHelper::GetWebkitPrefs(profile, is_web_ui);
- // Force accelerated compositing and 2d canvas off for chrome: and
- // chrome-extension: pages.
+ // Force accelerated compositing and 2d canvas off for chrome:, about: and
+ // chrome-devtools: pages.
if (GetURL().SchemeIs(chrome::kChromeDevToolsScheme) ||
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698